@@ -1,6 +1,6 @@
 package App::GitGot::Command::update_status;
 our $AUTHORITY = 'cpan:GENEHACK';
-$App::GitGot::Command::update_status::VERSION = '1.332';
+$App::GitGot::Command::update_status::VERSION = '1.333';
 # ABSTRACT: update managed repositories then display their status
 use 5.014;
 
@@ -10,6 +10,13 @@ use namespace::autoclean;
 
 sub command_names { qw/ update_status upst / }
 
+sub options {
+  my( $class , $app ) = @_;
+  return (
+    [ 'show-branch' => 'show which branch' => { default => 0 } ] ,
+  );
+}
+
 sub _execute {
   my ( $self, $opt, $args ) = @_;
 
@@ -36,7 +43,7 @@ App::GitGot::Command::update_status - update managed repositories then display t
 
 =head1 VERSION
 
-version 1.332
+version 1.333
 
 =head1 AUTHOR
 
